Learn R Programming

ibmcraftr (version 1.0.0)

rate2prob: Miscellaneous functions to support the ibmcraftr packare are here.

Description

Miscellaneous functions to support the ibmcraftr packare are here.

Usage

rate2prob(rates)

Arguments

rates
A numeric scalar or vector to be transformed into rates.

Value

A numeric scalar or vector in terms of probabilities.

Examples

Run this code
rate2prob(c(.1, .5))

Run the code above in your browser using DataLab