Take in the matrix of the states of synthetic population (created by syn_pop function)
and calculate the transitions from one state to other state(s) using the transition probabilities [not rate(s)].
The major difference from the R alone version was that instead of having the transition rate(s),
transition probabilities are used. These probabilities will thus be calculated with another function.
Usage
stRCPP(origin, new.states, params, s.matrix)
Arguments
origin
A number which represents the column index s.matrix you want to do the transition from
new.states
A numeric vector or a number which represents the column index s.matrix you want
as the destination(s) for the transition
params
A numeric vector of similar length to new.states which serves as the transition rate(s)
s.matrix
A state matrix created from syn_pop function
Value
A transition matrix of the same dimension as s.matrix. -1 indicates that the individual has left
the corresponding state. +1 indicates that the individual has become the corresponding state.